==> ejc-zdsmaterialb-api-3.0.0-20241114.025133-43-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/FeePackageVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 费用包实体
 * 
 * @author generator
 * 
 */
public class FeePackageVO extends BaseVO {

    private static final long serialVersionUID = 6080496444767808900L;
    private String sourceId; // 费用包ERP主键 C_PCM_ContractLimited_SubAOID
    private Long projectId; // 项目id
    private String projectName; // 项目名称 Account_Project_shortname
    private String projectCode; // 项目编码 Account_Project_id
    private String projectSid; // ERP项目主键 C_CM_AccountingProjectSetOID
    private Long businessContractId; // 商务合同id
    private String businessContractName; // 商务合同名称 Title
    private String businessContractCode; // 商务合同编码 CommerceCode
    private String businessContractSid; // ERP商务合同主键 ContractLimited_FK
    private String materialPackageCode; // 材料编码 MaterialPackageCode
    private String inventoryClassifyName; // 材料名称 InventoryClassifyName
    private String chargeTypeName; // 费用类别 ChargeTypeName
    private String contractMoney; // 上包合同额 ContractMoney
    private String executeLimited; // 执行限价(预算) ExecuteLimited
    private String systemClassifyName; // 系统分类 SystemClassifyName
    private String systemClassifyCode; // 系统分类SID SystemClassifyCode
    private String inventoryClassifySid; // 材料分类SID InventoryClassifySid
    private String inventoryClassifyCode; //材料分类编码

    public String getInventoryClassifyCode() {
        return inventoryClassifyCode;
    }

    public void setInventoryClassifyCode(String inventoryClassifyCode) {
        this.inventoryClassifyCode = inventoryClassifyCode;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectSid() {
        return projectSid;
    }

    public void setProjectSid(String projectSid) {
        this.projectSid = projectSid;
    }

    public Long getBusinessContractId() {
        return businessContractId;
    }

    public void setBusinessContractId(Long businessContractId) {
        this.businessContractId = businessContractId;
    }

    public String getBusinessContractName() {
        return businessContractName;
    }

    public void setBusinessContractName(String businessContractName) {
        this.businessContractName = businessContractName;
    }

    public String getBusinessContractCode() {
        return businessContractCode;
    }

    public void setBusinessContractCode(String businessContractCode) {
        this.businessContractCode = businessContractCode;
    }

    public String getBusinessContractSid() {
        return businessContractSid;
    }

    public void setBusinessContractSid(String businessContractSid) {
        this.businessContractSid = businessContractSid;
    }

    public String getMaterialPackageCode() {
        return materialPackageCode;
    }

    public void setMaterialPackageCode(String materialPackageCode) {
        this.materialPackageCode = materialPackageCode;
    }

    public String getInventoryClassifyName() {
        return inventoryClassifyName;
    }

    public void setInventoryClassifyName(String inventoryClassifyName) {
        this.inventoryClassifyName = inventoryClassifyName;
    }

    public String getChargeTypeName() {
        return chargeTypeName;
    }

    public void setChargeTypeName(String chargeTypeName) {
        this.chargeTypeName = chargeTypeName;
    }

    public String getContractMoney() {
        return contractMoney;
    }

    public void setContractMoney(String contractMoney) {
        this.contractMoney = contractMoney;
    }

    public String getExecuteLimited() {
        return executeLimited;
    }

    public void setExecuteLimited(String executeLimited) {
        this.executeLimited = executeLimited;
    }

    public String getSystemClassifyName() {
        return systemClassifyName;
    }

    public void setSystemClassifyName(String systemClassifyName) {
        this.systemClassifyName = systemClassifyName;
    }

    public String getSystemClassifyCode() {
        return systemClassifyCode;
    }

    public void setSystemClassifyCode(String systemClassifyCode) {
        this.systemClassifyCode = systemClassifyCode;
    }

    public String getInventoryClassifySid() {
        return inventoryClassifySid;
    }

    public void setInventoryClassifySid(String inventoryClassifySid) {
        this.inventoryClassifySid = inventoryClassifySid;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20250808.084019-55-sources.jar: com/ejianc/business/zdsmaterial/erp/vo/FeePackageVO.java <==
package com.ejianc.business.zdsmaterial.erp.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 费用包实体
 * 
 * @author generator
 * 
 */
public class FeePackageVO extends BaseVO {

    private static final long serialVersionUID = 6080496444767808900L;
    private String sourceId; // 费用包ERP主键 C_PCM_ContractLimited_SubAOID
    private Long projectId; // 项目id
    private String projectName; // 项目名称 Account_Project_shortname
    private String projectCode; // 项目编码 Account_Project_id
    private String projectSid; // ERP项目主键 C_CM_AccountingProjectSetOID
    private Long businessContractId; // 商务合同id
    private String businessContractName; // 商务合同名称 Title
    private String businessContractCode; // 商务合同编码 CommerceCode
    private String businessContractSid; // ERP商务合同主键 ContractLimited_FK
    private String materialPackageCode; // 材料编码 MaterialPackageCode
    private String inventoryClassifyName; // 材料名称 InventoryClassifyName
    private String chargeTypeName; // 费用类别 ChargeTypeName
    private String contractMoney; // 上包合同额 ContractMoney
    private String executeLimited; // 执行限价(预算) ExecuteLimited
    private String systemClassifyName; // 系统分类 SystemClassifyName
    private String systemClassifyCode; // 系统分类SID SystemClassifyCode
    private String inventoryClassifySid; // 材料分类SID InventoryClassifySid
    private String inventoryClassifyCode; //材料分类编码
    private String packageScope; //包范围

    public String getPackageScope() {
        return packageScope;
    }

    public void setPackageScope(String packageScope) {
        this.packageScope = packageScope;
    }

    public String getInventoryClassifyCode() {
        return inventoryClassifyCode;
    }

    public void setInventoryClassifyCode(String inventoryClassifyCode) {
        this.inventoryClassifyCode = inventoryClassifyCode;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectSid() {
        return projectSid;
    }

    public void setProjectSid(String projectSid) {
        this.projectSid = projectSid;
    }

    public Long getBusinessContractId() {
        return businessContractId;
    }

    public void setBusinessContractId(Long businessContractId) {
        this.businessContractId = businessContractId;
    }

    public String getBusinessContractName() {
        return businessContractName;
    }

    public void setBusinessContractName(String businessContractName) {
        this.businessContractName = businessContractName;
    }

    public String getBusinessContractCode() {
        return businessContractCode;
    }

    public void setBusinessContractCode(String businessContractCode) {
        this.businessContractCode = businessContractCode;
    }

    public String getBusinessContractSid() {
        return businessContractSid;
    }

    public void setBusinessContractSid(String businessContractSid) {
        this.businessContractSid = businessContractSid;
    }

    public String getMaterialPackageCode() {
        return materialPackageCode;
    }

    public void setMaterialPackageCode(String materialPackageCode) {
        this.materialPackageCode = materialPackageCode;
    }

    public String getInventoryClassifyName() {
        return inventoryClassifyName;
    }

    public void setInventoryClassifyName(String inventoryClassifyName) {
        this.inventoryClassifyName = inventoryClassifyName;
    }

    public String getChargeTypeName() {
        return chargeTypeName;
    }

    public void setChargeTypeName(String chargeTypeName) {
        this.chargeTypeName = chargeTypeName;
    }

    public String getContractMoney() {
        return contractMoney;
    }

    public void setContractMoney(String contractMoney) {
        this.contractMoney = contractMoney;
    }

    public String getExecuteLimited() {
        return executeLimited;
    }

    public void setExecuteLimited(String executeLimited) {
        this.executeLimited = executeLimited;
    }

    public String getSystemClassifyName() {
        return systemClassifyName;
    }

    public void setSystemClassifyName(String systemClassifyName) {
        this.systemClassifyName = systemClassifyName;
    }

    public String getSystemClassifyCode() {
        return systemClassifyCode;
    }

    public void setSystemClassifyCode(String systemClassifyCode) {
        this.systemClassifyCode = systemClassifyCode;
    }

    public String getInventoryClassifySid() {
        return inventoryClassifySid;
    }

    public void setInventoryClassifySid(String inventoryClassifySid) {
        this.inventoryClassifySid = inventoryClassifySid;
    }
}
